@@ -55,12 +55,14 @@ bool DockPanel::load()
 bool DockPanel::init()
 {
     DockAdaptor* adaptor = new DockAdaptor(this);
+    Q_UNUSED(adaptor)
     QDBusConnection::sessionBus().registerService("org.deepin.ds.Dock");
     QDBusConnection::sessionBus().registerObject("/org/deepin/ds/Dock", "org.deepin.ds.Dock", this);
 
     // for old api compatible
     DockDBusProxy* proxy = new DockDBusProxy(this);
     DockFrontAdaptor* dockFrontAdaptor = new DockFrontAdaptor(proxy);
+    Q_UNUSED(dockFrontAdaptor)
     QDBusConnection::sessionBus().registerService("org.deepin.dde.Dock1");
     QDBusConnection::sessionBus().registerObject("/org/deepin/dde/Dock1", "org.deepin.dde.Dock1", proxy);
 
@@ -179,6 +181,11 @@ QRect DockPanel::geometry()
 }
 
 QRect DockPanel::frontendWindowRect()
+{
+    return frontendWindowRect(0, 0);
+}
+
+QRect DockPanel::frontendWindowRect(int transformOffsetX, int transformOffsetY)
 {
     if(!window()) return QRect();
 
@@ -190,17 +197,19 @@ QRect DockPanel::frontendWindowRect()
     switch (position()) {
         case Top:
             xOffset = (screenGeometry.width() - geometry.width()) / 2;
+            yOffset = transformOffsetY;
             break;
         case Bottom:
             xOffset = (screenGeometry.width() - geometry.width()) / 2;
-            yOffset = screenGeometry.height() - geometry.height();
+            yOffset = screenGeometry.height() - geometry.height() + transformOffsetY;
             break;
         case Right:
-            xOffset = screenGeometry.width() - geometry.width();
+            xOffset = screenGeometry.width() - geometry.width() + transformOffsetX;
             yOffset = (screenGeometry.height() - geometry.height()) / 2;
             break;
         case Left:
-            yOffset = screenGeometry.height() - geometry.height();
+            xOffset = transformOffsetX;
+            yOffset = (screenGeometry.height() - geometry.height()) / 2;
             break;
     }
 
@@ -335,6 +344,11 @@ void DockPanel::openDockSettings() const
         .call();
 }
 
+void DockPanel::notifyDockPositionChanged(int offsetX, int offsetY)
+{
+    Q_EMIT frontendWindowRectChanged(frontendWindowRect(offsetX, offsetY));
+}
+
 void DockPanel::launcherVisibleChanged(bool visible)
 {
     if (visible == m_launcherShown) return;
