@@ -51,6 +51,7 @@ public:
 
     QRect geometry();
     QRect frontendWindowRect();
+    QRect frontendWindowRect(int transformOffsetX, int transformOffsetY);
 
     HideState hideState();
 
@@ -79,6 +80,8 @@ public:
 
     Q_INVOKABLE void openDockSettings() const;
 
+    Q_INVOKABLE void notifyDockPositionChanged(int offsetX, int offsetY);
+
     bool showInPrimary() const;
     void setShowInPrimary(bool newShowInPrimary);
 
