@@ -8,11 +8,15 @@
 #include "dsglobal.h"
 #include "treelandwindowmanager.h"
 
+#include <DConfig>
+
 namespace dock {
 
 class ShowDesktop : public DS_NAMESPACE::DApplet
 {
     Q_OBJECT
+    Q_PROPERTY(bool visible READ visible WRITE setVisible NOTIFY visibleChanged)
+    
 public:
     explicit ShowDesktop(QObject *parent = nullptr);
     virtual bool init() override;
@@ -20,9 +24,20 @@ public:
 
     Q_INVOKABLE void toggleShowDesktop();
     Q_INVOKABLE bool checkNeedShowDesktop();
+    
+    bool visible() const;
+    void setVisible(bool visible);
+
+Q_SIGNALS:
+    void visibleChanged();
+
+private slots:
+    void onEnableShowDesktopChanged();
 
 private:
     TreelandWindowManager *m_windowManager;
+    Dtk::Core::DConfig *m_dockConfig;
+    bool m_visible;
 };
 
 }
