@@ -13,6 +13,7 @@
 #include "dockglobalelementmodel.h"
 #include "dsglobal.h"
 #include "globals.h"
+#include "hoverpreviewproxymodel.h"
 #include "itemmodel.h"
 #include "pluginfactory.h"
 #include "taskmanager.h"
@@ -22,6 +23,10 @@
 
 #include <QGuiApplication>
 #include <QStringLiteral>
+#include <QUrl>
+#include <QDir>
+#include <QStandardPaths>
+#include <DTrashManager>
 
 #include <appletbridge.h>
 
@@ -72,23 +77,12 @@ TaskManager::TaskManager(QObject *parent)
     , AbstractTaskManagerInterface(nullptr)
     , m_windowFullscreen(false)
 {
-    qRegisterMetaType<ObjectInterfaceMap>();
-    qDBusRegisterMetaType<ObjectInterfaceMap>();
-    qRegisterMetaType<ObjectMap>();
-    qDBusRegisterMetaType<ObjectMap>();
-    qDBusRegisterMetaType<QStringMap>();
-    qRegisterMetaType<QStringMap>();
-    qRegisterMetaType<PropMap>();
-    qDBusRegisterMetaType<PropMap>();
-    qDBusRegisterMetaType<QDBusObjectPath>();
-
     connect(Settings, &TaskManagerSettings::allowedForceQuitChanged, this, &TaskManager::allowedForceQuitChanged);
     connect(Settings, &TaskManagerSettings::windowSplitChanged, this, &TaskManager::windowSplitChanged);
 }
 
 bool TaskManager::load()
 {
-    loadDockedAppItems();
     auto platformName = QGuiApplication::platformName();
     if (QStringLiteral("wayland") == platformName) {
         m_windowMonitor.reset(new TreeLandWindowMonitor());
@@ -107,6 +101,7 @@ bool TaskManager::load()
 bool TaskManager::init()
 {
     auto adaptor = new TaskManagerAdaptor(this);
+    Q_UNUSED(adaptor)
     QDBusConnection::sessionBus().registerService("org.deepin.ds.Dock.TaskManager");
     QDBusConnection::sessionBus().registerObject("/org/deepin/ds/Dock/TaskManager", "org.deepin.ds.Dock.TaskManager", this);
 
@@ -143,16 +138,26 @@ bool TaskManager::init()
 
         m_dockGlobalElementModel = new DockGlobalElementModel(model, m_activeAppModel, this);
         m_itemModel = new DockItemModel(m_dockGlobalElementModel, this);
-    }
 
-    if (m_windowMonitor)
-        m_windowMonitor->start();
+        // 初始化预览代理模型，基于合并后的数据
+        m_hoverPreviewModel = new HoverPreviewProxyModel(this);
+        m_hoverPreviewModel->setSourceModel(m_dockGlobalElementModel);
+
+        connect(applet, SIGNAL(appModelReadyChanged(bool)), m_dockGlobalElementModel, SLOT(initDockedElements(bool)));
+    }
 
     connect(m_windowMonitor.data(), &AbstractWindowMonitor::windowFullscreenChanged, this, [this] (bool isFullscreen) {
         m_windowFullscreen = isFullscreen;
         emit windowFullscreenChanged(isFullscreen);
     });
 
+    connect(m_windowMonitor.data(), &AbstractWindowMonitor::previewShouldClear, this, [this]() {
+        // 当预览窗口真正隐藏时，清空过滤条件
+        if (m_hoverPreviewModel) {
+            m_hoverPreviewModel->clearFilter();
+        }
+    });
+
     // 设置preview opacity
     DS_NAMESPACE::DAppletBridge appearanceBridge("org.deepin.ds.dde-appearance");
     auto appearanceApplet = appearanceBridge.applet();
@@ -160,12 +165,22 @@ bool TaskManager::init()
         modifyOpacityChanged();
         connect(appearanceApplet, SIGNAL(opacityChanged()), this, SLOT(modifyOpacityChanged()));
     }
+    QTimer::singleShot(500, [this]() {
+        if (m_windowMonitor)
+            m_windowMonitor->start();
+    });
+
     return true;
 }
 
-ItemModel *TaskManager::dataModel()
+DockItemModel *TaskManager::dataModel() const
 {
-    return ItemModel::instance();
+    return m_itemModel;
+}
+
+HoverPreviewProxyModel *TaskManager::hoverPreviewModel() const
+{
+    return m_hoverPreviewModel;
 }
 
 void TaskManager::requestActivate(const QModelIndex &index) const
@@ -188,22 +203,31 @@ void TaskManager::requestClose(const QModelIndex &index, bool force) const
     m_itemModel->requestClose(index, force);
 }
 
-void TaskManager::requestUpdateWindowGeometry(const QModelIndex &index, const QRect &geometry, QObject *delegate) const
+void TaskManager::requestUpdateWindowIconGeometry(const QModelIndex &index, const QRect &geometry, QObject *delegate) const
 {
-    m_itemModel->requestUpdateWindowGeometry(index, geometry, delegate);
+    m_itemModel->requestUpdateWindowIconGeometry(index, geometry, delegate);
 }
 
-void TaskManager::requestPreview(const QModelIndexList &indexes,
-                                 QObject *relativePositionItem,
-                                 int32_t previewXoffset,
-                                 int32_t previewYoffset,
-                                 uint32_t direction) const
+void TaskManager::requestPreview(const QModelIndex &index, QObject *relativePositionItem, int32_t previewXoffset, int32_t previewYoffset, uint32_t direction)
 {
-    for (auto index : indexes) {
-        qDebug() << "requestPreview" << index << index.model() << (index.model() == m_itemModel);
+    if (!m_hoverPreviewModel) {
+        qCWarning(taskManagerLog) << "TaskManager::requestPreview: m_hoverPreviewModel is null";
+        return;
     }
-    m_itemModel->requestPreview(indexes, relativePositionItem, previewXoffset, previewYoffset, direction);
+
+    // Set the preview filter condition based on the incoming model index
+    m_hoverPreviewModel->setFilterModelIndex(index);
+
+    // Check if there are any windows after filtering
+    if (m_hoverPreviewModel->rowCount() == 0) {
+        qCDebug(taskManagerLog) << "TaskManager::requestPreview: No windows found for index";
+        hideItemPreview();
+        return;
+    }
+
+    m_windowMonitor->requestPreview(m_hoverPreviewModel, qobject_cast<QWindow *>(relativePositionItem), previewXoffset, previewYoffset, direction);
 }
+
 void TaskManager::requestWindowsView(const QModelIndexList &indexes) const
 {
     m_itemModel->requestWindowsView(indexes);
@@ -223,17 +247,17 @@ void TaskManager::handleWindowAdded(QPointer<AbstractWindow> window)
     QString desktopId;
     if (res.size() > 0) {
         desktopId = res.first().data(m_activeAppModel->roleNames().key("desktopId")).toString();
-        qCDebug(taskManagerLog()) << "identify bt model:" << desktopId;
+        qCDebug(taskManagerLog()) << "identify by model:" << desktopId;
     }
 
     if (!desktopId.isEmpty()) {
         desktopfile = DESKTOPFILEFACTORY::createById(desktopId, "amAPP");
-        qCDebug(taskManagerLog()) <<  "identify bt AM:" << desktopId;
+        qCDebug(taskManagerLog()) << "identify by AM:" << desktopId;
     }
 
-    if (desktopfile.isNull() || !desktopfile->isValied().first) {
+    if (Settings->cgroupsBasedGrouping() && (desktopfile.isNull() || !desktopfile->isValied().first)) {
         desktopfile = DESKTOPFILEFACTORY::createByWindow(window);
-        qCDebug(taskManagerLog()) <<  "identify bt Fallback:" << desktopId;
+        qCDebug(taskManagerLog()) << "identify by Fallback:" << desktopId;
     }
 
     auto appitem = desktopfile->getAppItem();
@@ -249,46 +273,40 @@ void TaskManager::handleWindowAdded(QPointer<AbstractWindow> window)
     ItemModel::instance()->addItem(appitem);
 }
 
-void TaskManager::clickItem(const QString& itemId, const QString& menuId)
-{
-    auto item = ItemModel::instance()->getItemById(itemId);
-    if(!item) return;
-
-    if (menuId == DOCK_ACTION_ALLWINDOW) {
-        QList<uint32_t> windowIds;
-        auto windows = item->data().toStringList();
-        std::transform(windows.begin(), windows.end(), std::back_inserter(windowIds), [](const QString &windowId) {
-            return windowId.toUInt();
-        });
-
-        m_windowMonitor->presentWindows(windowIds);
-        return;
-    }
-
-    item->handleClick(menuId);
-}
-
 void TaskManager::dropFilesOnItem(const QString& itemId, const QStringList& urls)
 {
-    auto item = ItemModel::instance()->getItemById(itemId);
-    if(!item) return;
+    if (itemId == "dde-trash") {
+        qCDebug(taskManagerLog) << "dropFilesOnItem: dde-trash - moving files to trash:" << urls;
+        // 将文件移动到回收站
+        moveFilesToTrash(urls);
+        return;
+    }
 
-    item->handleFileDrop(urls);
+    auto indexes = m_itemModel->match(m_itemModel->index(0, 0), TaskManager::ItemIdRole, itemId, 1, Qt::MatchExactly);
+    if (indexes.isEmpty()) {
+        return;
+    }
+
+    QList<QUrl> urlList;
+    for (const QString &url : urls) {
+        urlList.append(QUrl::fromLocalFile(url));
+    }
+
+    m_itemModel->requestOpenUrls(indexes.first(), urlList);
 }
 
-void TaskManager::showItemPreview(const QString &itemId, QObject *relativePositionItem, int32_t previewXoffset, int32_t previewYoffset, uint32_t direction)
+void TaskManager::moveFilesToTrash(const QStringList& urls)
 {
-    auto item = ItemModel::instance()->getItemById(itemId).get();
-    if (!item) {
-        return;
+    // 将文件路径转换为本地路径并移动到回收站
+    for (const QString& urlString : urls) {
+        QUrl url(urlString);
+        QString filePath = url.toLocalFile();
+        if (DTrashManager::instance()->moveToTrash(filePath)) {
+            qCDebug(taskManagerLog) << "Successfully moved to trash:" << filePath;
+        } else {
+            qCWarning(taskManagerLog) << "Failed to move to trash:" << filePath;
+        }
     }
-
-    QPointer<AppItem> pItem = reinterpret_cast<AppItem *>(item);
-    if (pItem.isNull()) {
-        return;
-    }
-
-    m_windowMonitor->showItemPreview(pItem, relativePositionItem, previewXoffset, previewYoffset, direction);
 }
 
 void TaskManager::hideItemPreview()
@@ -296,41 +314,6 @@ void TaskManager::hideItemPreview()
     m_windowMonitor->hideItemPreview();
 }
 
-void TaskManager::setAppItemWindowIconGeometry(const QString& appid, QObject* relativePositionItem, const int& x1, const int& y1, const int& x2, const int& y2)
-{
-    QPointer<AppItem> item = static_cast<AppItem*>(ItemModel::instance()->getItemById(appid).get());
-    if (item.isNull()) return;
-
-    for (auto window : item->getAppendWindows()) {
-        window->setWindowIconGeometry(qobject_cast<QWindow*>(relativePositionItem), QRect(QPoint(x1, y1),QPoint(x2, y2)));
-    }
-}
-
-void TaskManager::loadDockedAppItems()
-{
-    // TODO: add support for group and dir type
-    for (const auto& appValueRef : TaskManagerSettings::instance()->dockedDesktopFiles()) {
-        auto app = appValueRef.toObject();
-        auto appid = app.value("id").toString();
-        auto type = app.value("type").toString();
-        auto desktopfile = DESKTOPFILEFACTORY::createById(appid, type);
-        auto valid = desktopfile->isValied();
-
-        if (!valid.first) {
-            qInfo(taskManagerLog()) << "failed to load " << appid << " beacause " << valid.second;
-            continue;
-        }
-
-        auto appitem = desktopfile->getAppItem();
-        if (appitem.isNull()) {
-            appitem = new AppItem(appid);
-        }
-
-        appitem->setDesktopFileParser(desktopfile);
-        ItemModel::instance()->addItem(appitem);
-    }
-}
-
 bool TaskManager::allowForceQuit()
 {
     return Settings->isAllowedForceQuit();
@@ -344,7 +327,12 @@ QString TaskManager::desktopIdToAppId(const QString& desktopId)
 bool TaskManager::requestDockByDesktopId(const QString& desktopID)
 {
     if (desktopID.startsWith("internal/")) return false;
-    return RequestDock(desktopIdToAppId(desktopID));
+    QString appId = desktopIdToAppId(desktopID);
+    // 检查应用是否已经在任务栏中，如果是则返回 false
+    if (IsDocked(appId))
+        return false;
+
+    return RequestDock(appId);
 }
 
 bool TaskManager::requestUndockByDesktopId(const QString& desktopID)
@@ -421,11 +409,38 @@ void TaskManager::activateWindow(uint32_t windowID)
 #ifdef BUILD_WITH_X11
     X11Utils::instance()->setActiveWindow(static_cast<xcb_window_t>(windowID));
 #else
-    qWarning() << "activateWindow not supported on this platform";
+    qCWarning(taskManagerLog) << "activateWindow not supported on this platform";
     Q_UNUSED(windowID)
 #endif
 }
 
+void TaskManager::saveDockElementsOrder(const QStringList &appIds)
+{
+    const QStringList &dockedElements = TaskManagerSettings::instance()->dockedElements();
+    QStringList newDockedElements;
+    for (const auto &appId : appIds) {
+        auto desktopElement = QString("desktop/%1").arg(appId);
+        if (dockedElements.contains(desktopElement) && !newDockedElements.contains(desktopElement)) {
+            newDockedElements.append(desktopElement);
+        }
+    }
+    TaskManagerSettings::instance()->setDockedElements(newDockedElements);
+}
+
+QString TaskManager::getTrashTipText()
+{
+    int fileCount = 0;
+    QString trashPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/Trash/files";
+    QDir trashDir(trashPath);
+    
+    if (trashDir.exists()) {
+        QStringList entries = trashDir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot);
+        fileCount = entries.size();
+    }
+
+    return tr("%1 files").arg(fileCount);
+}
+
 void TaskManager::modifyOpacityChanged()
 {
     DS_NAMESPACE::DAppletBridge appearanceBridge("org.deepin.ds.dde-appearance");
@@ -436,7 +451,7 @@ void TaskManager::modifyOpacityChanged()
             x11Monitor->setPreviewOpacity(opacity);
         }
     } else {
-        qWarning() << "modifyOpacityChanged: appearanceApplet is null";
+        qCWarning(taskManagerLog) << "modifyOpacityChanged: appearanceApplet is null";
     }
 }
 
