@@ -1,4 +1,20 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="ja">
+<context>
+    <name>AppItem</name>
+    <message>
+        <source>Move to Trash</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AppItem</name>
+    <message>
+        <source>Move to Trash</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>dock::AppItem</name>
     <message>
@@ -45,4 +61,11 @@
         <translation>すべて閉じる</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>dock::TaskManager</name>
+    <message>
+        <source>%1 files</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+</TS>
