@@ -1,4 +1,20 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="pt_BR">
+<context>
+    <name>AppItem</name>
+    <message>
+        <source>Move to Trash</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AppItem</name>
+    <message>
+        <source>Move to Trash</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>dock::AppItem</name>
     <message>
@@ -11,11 +27,11 @@
     </message>
     <message>
         <source>Dock</source>
-        <translation>Dock</translation>
+        <translation>Fixar no dock</translation>
     </message>
     <message>
         <source>Force Quit</source>
-        <translation>Forçar encerramento</translation>
+        <translation>Forçar encerrar</translation>
     </message>
     <message>
         <source>Close All</source>
@@ -30,19 +46,26 @@
     </message>
     <message>
         <source>Undock</source>
-        <translation>Desencaixar</translation>
+        <translation>Remover do dock</translation>
     </message>
     <message>
         <source>Dock</source>
-        <translation>Dock</translation>
+        <translation>Fixar no dock</translation>
     </message>
     <message>
         <source>Force Quit</source>
-        <translation>Forçar saída</translation>
+        <translation>Forçar encerrar</translation>
     </message>
     <message>
         <source>Close All</source>
         <translation>Fechar tudo</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>dock::TaskManager</name>
+    <message>
+        <source>%1 files</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+</TS>
