@@ -1,4 +1,20 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="zh_CN">
+<context>
+    <name>AppItem</name>
+    <message>
+        <source>Move to Trash</source>
+        <translation>移动到回收站</translation>
+    </message>
+</context>
+<context>
+    <name>AppItem</name>
+    <message>
+        <source>Move to Trash</source>
+        <translation>移动到回收站</translation>
+    </message>
+</context>
 <context>
     <name>dock::AppItem</name>
     <message>
@@ -45,4 +61,11 @@
         <translation>关闭所有</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>dock::TaskManager</name>
+    <message>
+        <source>%1 files</source>
+        <translation>%1个文件</translation>
+    </message>
+</context>
+</TS>
