@@ -75,6 +75,8 @@ void ForeignToplevelHandle::treeland_foreign_toplevel_handle_v1_app_id(const QSt
 {
     if (app_id == m_appId) return;
     m_appId = app_id;
+
+    Q_EMIT appidChanged();
 }
 
 void ForeignToplevelHandle::treeland_foreign_toplevel_handle_v1_identifier(uint32_t identifier)
@@ -93,13 +95,15 @@ void ForeignToplevelHandle::treeland_foreign_toplevel_handle_v1_state(wl_array *
         m_states.append(items[i]);
     }
 
-    Q_EMIT isActiveChanged();
+    Q_EMIT stateChanged();
 }
 
 void ForeignToplevelHandle::treeland_foreign_toplevel_handle_v1_done()
 {
-    m_isReady = true;
-    Q_EMIT handlerIsReady();
+    if (!m_isReady) {
+        m_isReady = true;
+        Q_EMIT handlerIsReady();
+    }
 }
 void ForeignToplevelHandle::treeland_foreign_toplevel_handle_v1_closed()
 {
@@ -116,6 +120,7 @@ TreeLandWindow::TreeLandWindow(uint32_t id, QObject *parent)
 TreeLandWindow::~TreeLandWindow()
 {
     qCDebug(waylandwindowLog()) << "wayland window destoryed";
+    emit stateChanged();
 }
 
 uint32_t TreeLandWindow::id()
@@ -158,6 +163,11 @@ bool TreeLandWindow::isMinimized()
     return m_foreignToplevelHandle->state().contains(Minimized);
 }
 
+bool TreeLandWindow::isFullscreen()
+{
+    return m_foreignToplevelHandle->state().contains(Fullscreen);
+}
+
 bool TreeLandWindow::allowClose()
 {
     return true;
@@ -200,6 +210,9 @@ void TreeLandWindow::killClient()
 void TreeLandWindow::setWindowIconGeometry(const QWindow* baseWindow, const QRect& gemeotry)
 {
     auto waylandWindow = dynamic_cast<QtWaylandClient::QWaylandWindow*>(baseWindow->handle());
+    if (waylandWindow->surface() == nullptr || gemeotry.isEmpty())
+        return;
+
     m_foreignToplevelHandle->set_rectangle(waylandWindow->surface(), gemeotry.x(), gemeotry.y(), gemeotry.width(), gemeotry.height());
 }
 
@@ -214,9 +227,10 @@ void TreeLandWindow::setForeignToplevelHandle(ForeignToplevelHandle* handle)
     m_foreignToplevelHandle.reset(handle);
     m_id = m_foreignToplevelHandle->id();
 
+    connect(m_foreignToplevelHandle.get(), &ForeignToplevelHandle::appidChanged, this, &AbstractWindow::identityChanged);
     connect(m_foreignToplevelHandle.get(), &ForeignToplevelHandle::pidChanged, this, &AbstractWindow::pidChanged);
     connect(m_foreignToplevelHandle.get(), &ForeignToplevelHandle::titleChanged, this, &AbstractWindow::titleChanged);
-    connect(m_foreignToplevelHandle.get(), &ForeignToplevelHandle::isActiveChanged, this, &AbstractWindow::isActiveChanged);
+    connect(m_foreignToplevelHandle.get(), &ForeignToplevelHandle::stateChanged, this, &AbstractWindow::stateChanged);
 }
 
 }
