@@ -4,8 +4,8 @@
 
 #include "x11window.h"
 #include "abstractwindow.h"
-#include "dsglobal.h"
 #include "x11utils.h"
+#include "appitem.h"
 
 #include <mutex>
 
@@ -49,6 +49,12 @@ QStringList X11Window::identity()
 {
     if (m_identity.isEmpty()) {
         m_identity = X11->getWindowWMClass(m_windowID);
+        if (auto appItem = getAppItem()) {
+            m_identity.append(appItem->desktopfileID());
+        } else {
+            qCWarning(x11windowLog) << "identify not found appitem." << id();
+        }
+        m_identity.append(QString::number(pid()));
     }
 
     return m_identity;
@@ -168,11 +174,12 @@ void X11Window::updatePid()
 
 void X11Window::updateIdentify()
 {
-    auto newWmclas = X11->getWindowWMClass(m_windowID);
-    if (newWmclas == m_identity)
+    auto newWMclass = X11->getWindowWMClass(m_windowID);
+    newWMclass.append(QString::number(pid()));
+    if (newWMclass == m_identity)
         return;
 
-    m_identity = newWmclas;
+    m_identity = newWMclass;
     Q_EMIT identityChanged();
 }
 
