@@ -2,7 +2,6 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include "appitem.h"
 #include "x11utils.h"
 #include "x11window.h"
 #include "x11preview.h"
@@ -103,21 +102,6 @@ void X11WindowMonitor::presentWindows(QList<uint32_t> windows)
                 .call().waitForFinished();
 }
 
-void X11WindowMonitor::showItemPreview(const QPointer<AppItem> &item, QObject* relativePositionItem, int32_t previewXoffset, int32_t previewYoffset, uint32_t direction)
-{
-    // custom created preview popup window and show at (relativePositionItem.x + previewXoffset, relativePositionItem.y + previewYoffset) pos
-    // direction is dock current position
-
-    if (m_windowPreview.isNull()) {
-        m_windowPreview.reset(new X11WindowPreviewContainer(this));
-        m_windowPreview->setMaskAlpha(static_cast<int>(m_opacity * 255));
-        m_windowPreview->windowHandle()->setTransientParent(qobject_cast<QWindow *>(relativePositionItem));
-    }
-
-    m_windowPreview->showPreview(item,qobject_cast<QWindow*>(relativePositionItem), previewXoffset, previewYoffset, direction);
-    m_windowPreview->updatePosition();
-}
-
 void X11WindowMonitor::hideItemPreview()
 {
     if (m_windowPreview.isNull()) return;
@@ -151,6 +135,35 @@ void X11WindowMonitor::setPreviewOpacity(double opacity)
     }
 }
 
+void X11WindowMonitor::requestPreview(QAbstractItemModel *sourceModel,
+                                      QWindow *relativePositionItem,
+                                      int32_t previewXoffset,
+                                      int32_t previewYoffset,
+                                      uint32_t direction)
+{
+    if (m_windowPreview.isNull()) {
+        m_windowPreview.reset(new X11WindowPreviewContainer(this));
+        m_windowPreview->setMaskAlpha(static_cast<int>(m_opacity * 255));
+        m_windowPreview->windowHandle()->setTransientParent(relativePositionItem);
+    }
+
+    m_windowPreview->showPreviewWithModel(sourceModel, relativePositionItem, previewXoffset, previewYoffset, direction);
+    m_windowPreview->updatePosition();
+}
+
+void X11WindowMonitor::requestUpdateWindowIconGeometry(const QModelIndex &index, const QRect &geometry, QObject *delegate) const
+{
+    xcb_window_t winId = index.data(TaskManager::WinIdRole).toUInt();
+    auto pos = qobject_cast<QWindow *>(delegate)->position() + geometry.topLeft();
+    X11->setWindowIconGemeotry(winId, QRect(pos.x(), pos.y(), geometry.width(), geometry.height()));
+}
+
+void X11WindowMonitor::clearPreviewState()
+{
+    // 发出信号通知 TaskManager 清空预览过滤状态
+    emit previewShouldClear();
+}
+
 void X11WindowMonitor::onWindowMapped(xcb_window_t xcb_window)
 {
     auto window = m_windows.value(xcb_window, nullptr);
@@ -162,8 +175,9 @@ void X11WindowMonitor::onWindowMapped(xcb_window_t xcb_window)
 
     uint32_t value_list[] = { XCB_EVENT_MASK_PROPERTY_CHANGE | XCB_EVENT_MASK_STRUCTURE_NOTIFY | XCB_EVENT_MASK_VISIBILITY_CHANGE};
     xcb_change_window_attributes(X11->getXcbConnection(), xcb_window, XCB_CW_EVENT_MASK, value_list);
-    trackWindow(window.get());
     Q_EMIT AbstractWindowMonitor::windowAdded(static_cast<QPointer<AbstractWindow>>(window.get()));
+    trackWindow(window.get());
+
 }
 
 void X11WindowMonitor::onWindowDestroyed(xcb_window_t xcb_window)
@@ -204,11 +218,6 @@ void X11WindowMonitor::onWindowPropertyChanged(xcb_window_t window, xcb_atom_t a
     } else if (atom == X11->getAtomByName("WM_CLASS")) {
         x11Window->updateIdentify();
     }
-
-    auto appitem = x11Window->getAppItem();
-    if (x11Window->shouldSkip() && appitem) {
-        appitem->removeWindow(x11Window.data());
-    }
 }
 
 void X11WindowMonitor::handleRootWindowPropertyNotifyEvent(xcb_atom_t atom)
