@@ -3,14 +3,14 @@
     <name>ActionShowStashDelegate</name>
     <message>
         <source>Application tray</source>
-        <translation>App-Tableau</translation>
+        <translation>App-Palette</translation>
     </message>
 </context>
 <context>
     <name>ActionToggleCollapseDelegate</name>
     <message>
         <source>Collapse tray</source>
-        <translation>Leiste auf-/zuklappen</translation>
+        <translation>Leiste aus-/einfahren</translation>
     </message>
 </context>
 <context>
