@@ -1,11 +1,9 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ru">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
 <context>
     <name>notification::BubbleItem</name>
     <message>
         <source>just now</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>1 new message</source>
@@ -19,4 +17,4 @@
         <translation>%1 минут назад</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
