@@ -1,10 +1,27 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="ca">
 <context>
     <name>GroupNotify</name>
     <message>
         <source>Clear All</source>
         <translation>Neteja-ho tot</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Replega</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Més</translation>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation>No hi ha notificacions recents.</translation>
+    </message>
 </context>
 <context>
     <name>NotifyHeader</name>
@@ -16,6 +33,14 @@
         <source>Clear All</source>
         <translation>Neteja-ho tot</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Replega</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Més</translation>
+    </message>
 </context>
 <context>
     <name>NotifySetting</name>
@@ -32,27 +57,18 @@
         <translation>Configuració de les notificacions</translation>
     </message>
 </context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation type="unfinished">Neteja-ho tot</translation>
+    </message>
+</context>
 <context>
     <name>notifycenter::AppNotifyItem</name>
     <message>
         <source>Just now</source>
         <translation>Ara mateix</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>Fa %1 minuts</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation>Fa 1 hora</translation>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>Fa %1 hores</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Ahir</translation>
-    </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
