@@ -5,6 +5,21 @@
         <source>Clear All</source>
         <translation>Alles wissen</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Invouwen</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Meer</translation>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation>Er zijn geen meldingen</translation>
+    </message>
 </context>
 <context>
     <name>NotifyHeader</name>
@@ -16,6 +31,14 @@
         <source>Clear All</source>
         <translation>Alles wissen</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Invouwen</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Meer</translation>
+    </message>
 </context>
 <context>
     <name>NotifySetting</name>
@@ -32,27 +55,18 @@
         <translation>Meldingsinstellingen</translation>
     </message>
 </context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation>Alles wissen</translation>
+    </message>
+</context>
 <context>
     <name>notifycenter::AppNotifyItem</name>
     <message>
         <source>Just now</source>
         <translation>Zojuist</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>%1 minuten geleden</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation>1 uur geleden</translation>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>%1 uur geleden</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Gisteren</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
