@@ -1,27 +1,52 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="ru">
 <context>
     <name>GroupNotify</name>
     <message>
         <source>Clear All</source>
         <translation>Очистить всё</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NotifyHeader</name>
     <message>
         <source>Notification Center</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Clear All</source>
         <translation>Очистить всё</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NotifySetting</name>
     <message>
         <source>Unpin</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Pin</source>
@@ -29,7 +54,14 @@
     </message>
     <message>
         <source>Notification Setting</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -38,21 +70,5 @@
         <source>Just now</source>
         <translation>Сейчас</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>%1 минут назад</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>1% часов назад</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Вчера</translation>
-    </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
