@@ -1,10 +1,27 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="sq">
 <context>
     <name>GroupNotify</name>
     <message>
         <source>Clear All</source>
         <translation>Spastroji Krejt</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Palose</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Më tepër</translation>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation>S’ka njoftime së fundi</translation>
+    </message>
 </context>
 <context>
     <name>NotifyHeader</name>
@@ -16,6 +33,14 @@
         <source>Clear All</source>
         <translation>Spastroji Krejt</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Palose</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Më tepër</translation>
+    </message>
 </context>
 <context>
     <name>NotifySetting</name>
@@ -32,27 +57,18 @@
         <translation>Rregullime Njoftimesh</translation>
     </message>
 </context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation>Spastroji Krejt</translation>
+    </message>
+</context>
 <context>
     <name>notifycenter::AppNotifyItem</name>
     <message>
         <source>Just now</source>
         <translation>Mu tani</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>%1 minuta më parë</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation>1 orë më parë</translation>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>%1 orë më parë</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Dje </translation>
-    </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
