@@ -5,6 +5,21 @@
         <source>Clear All</source>
         <translation>Tümünü Temizle</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>More</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>NotifyHeader</name>
@@ -16,6 +31,14 @@
         <source>Clear All</source>
         <translation>Tümünü Temizle</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>More</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>NotifySetting</name>
@@ -32,27 +55,18 @@
         <translation>Bildirim Ayarı</translation>
     </message>
 </context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>notifycenter::AppNotifyItem</name>
     <message>
         <source>Just now</source>
         <translation>Hemen şimdi</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>%1 dakika önce</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation>1 saat önce</translation>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>%1 saat önce</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Dün</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
