@@ -3,7 +3,22 @@
     <name>GroupNotify</name>
     <message>
         <source>Clear All</source>
-        <translation>全部清除</translation>
+        <translation>清除全部</translation>
+    </message>
+    <message>
+        <source>Fold</source>
+        <translation>收起</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>更多</translation>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation>没有最近的通知</translation>
     </message>
 </context>
 <context>
@@ -14,7 +29,15 @@
     </message>
     <message>
         <source>Clear All</source>
-        <translation>全部清除</translation>
+        <translation>清除全部</translation>
+    </message>
+    <message>
+        <source>Fold</source>
+        <translation>折叠</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>更多</translation>
     </message>
 </context>
 <context>
@@ -32,27 +55,18 @@
         <translation>通知设置</translation>
     </message>
 </context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation>清除全部</translation>
+    </message>
+</context>
 <context>
     <name>notifycenter::AppNotifyItem</name>
     <message>
         <source>Just now</source>
         <translation>刚刚</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>%1分钟前</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation>1小时前</translation>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>%1小时前</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>昨天 </translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
