@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>غلق وضع الطائرة</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>فتح الصمت</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>غلق الصمت</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>طاقة متوازنة</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>فشل في تفعيل تأثيرات النافذة</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
