@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>এয়ারপ্লেন মোড বন্ধ</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>মিউট চালু</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>মিউট বন্ধ</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>পরিষ্কার শক্তি</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>বিংগো ফেরতিই চালু করতে ব্যর্থ হয়েছে</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
