@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Mode d&apos;avió desactivat</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Silenci activat</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Silenci desactivat</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Energia equilibrada</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Ha fallat activar els efectes de les finestres.</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>Micròfon tancat</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>Micròfon obert</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
