@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Flugmodus aus</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Stumm an</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Stumm aus</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Ausgewogener Stromverbrauch</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Fenstereffekt anschalten schlug fehl</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
