@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Modo avión desactivado.</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Silencio activado.</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Silencio desactivado.</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Energía equilibrada</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Error al activar efectos de ventana</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>Micrófono apagado</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>Micrófono encendido</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
