@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Lentotila pois</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Mykistys päällä</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Mykistys pois</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Tasapainoinen teho</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Ikkunatehosteiden käyttöönotto epäonnistui</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>Mikrofoni pois</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>Mikrofoni on</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
