@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Mode avion désactivé</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Sourdine activée</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Sourdine désactivée</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Mode d&apos;énergie équilibré</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Impossible d&apos;activer les effets de fenêtres</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>Microphone désactivé</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>Microphone activé</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
