@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Modo avión desactivado</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Silencio activado</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Silencio desactivado</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Potencia equilibrada</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>No se pudo activar los efectos de ventana</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
