@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Repülőgép üzemmód kikapcsolva</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Némítás bekapcsolva</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Némítás kikapcsolva</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Kiegyensúlyozott teljesítmény</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Az ablakeffektusok engedélyezése sikertelen</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
