@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>機内モードOFF</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>ミュート ON</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>ミュート OFF</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>バランス</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>ウィンドウ エフェクトを有効化できませんでした</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>マイクOFF</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>マイクON</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
