@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Соңырақ режимі жетісі бекітілген</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Кемет жетісі</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Кемет жетісі бекітілген</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Жалпысыз энергиялық режим</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Квадраттардың ефекті әртүрлі кестесін қатыстыру қателесі</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
