@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Tryb samolotowy wyłączony</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Wyciszenie włączone</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Wyciszenie wyłączone</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Zasilanie zrównoważone</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Nie udało się włączyć niektórych efektów okna</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>Mikrofon wyłączony</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>Mikrofon włączony</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
