@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Modo avião desativado</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Mudo ativado</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Mudo desativado</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Equilibrado</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Falha ao ativar os efeitos visuais</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>Microfone desligado</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>Microfone ligado</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
