@@ -3,35 +3,35 @@
     <name>main</name>
     <message>
         <source>WLAN on</source>
-        <translation>WLAN вкл</translation>
+        <translation>WiFi вкл.</translation>
     </message>
     <message>
         <source>WLAN off</source>
-        <translation>WLAN выкл</translation>
+        <translation>WiFi выкл.</translation>
     </message>
     <message>
         <source>Caps Lock on</source>
-        <translation>Caps Lock вкл</translation>
+        <translation>Caps Lock вкл.</translation>
     </message>
     <message>
         <source>Caps Lock off</source>
-        <translation>Caps Lock выкл</translation>
+        <translation>Caps Lock выкл.</translation>
     </message>
     <message>
         <source>Numeric keypad on</source>
-        <translation>Цифровая клавиатура вкл</translation>
+        <translation>Цифровая клавиатура вкл.</translation>
     </message>
     <message>
         <source>Numeric keypad off</source>
-        <translation>Цифровая клавиатура выкл</translation>
+        <translation>Цифровая клавиатура выкл.</translation>
     </message>
     <message>
         <source>Touchpad on</source>
-        <translation>Тачпад вкл</translation>
+        <translation>Тачпад вкл.</translation>
     </message>
     <message>
         <source>Touchpad off</source>
-        <translation>Тачпад выкл</translation>
+        <translation>Тачпад выкл.</translation>
     </message>
     <message>
         <source>Touchpad toggle</source>
@@ -43,27 +43,19 @@
     </message>
     <message>
         <source>Airplane mode on</source>
-        <translation>Авиарежим вкл </translation>
+        <translation>Режим полета вкл.</translation>
     </message>
     <message>
         <source>Airplane mode off</source>
-        <translation>Авиарежим выкл </translation>
-    </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Звук выкл</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Звук вкл</translation>
+        <translation>Режим полета выкл.</translation>
     </message>
     <message>
         <source>Balanced power</source>
-        <translation>Сбалансированный режим</translation>
+        <translation>Сбалансированный</translation>
     </message>
     <message>
         <source>Power saver</source>
-        <translation>Экономия заряда</translation>
+        <translation>Экономия энергии</translation>
     </message>
     <message>
         <source>High performance</source>
@@ -71,15 +63,23 @@
     </message>
     <message>
         <source>Window effect enabled</source>
-        <translation>Оконные эффекты вкл</translation>
+        <translation>Оконные эффекты вкл.</translation>
     </message>
     <message>
         <source>Window effect disabled</source>
-        <translation>Оконные эффекты выкл</translation>
+        <translation>Оконные эффекты выкл.</translation>
     </message>
     <message>
         <source>Failed to enable window effects</source>
         <translation>Не удалось включить эффекты окон</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
