@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Režim letalnice izključen</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Zapiranje zvoka vključeno</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Zapiranje zvoka izključeno</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Izdelava balansirana</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Napaka pri omogočanju efektov okna</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
