@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Mënyra aeroplan joaktive</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Me heshtim</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Pa heshtim</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Balancim energjie</translation>
@@ -67,7 +59,7 @@
     </message>
     <message>
         <source>High performance</source>
-        <translation>Këshilla higëzuar</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Window effect enabled</source>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>S’u arrit të aktivizohen efekte dritaresh</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>Mikrofoni fikur</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>Mikrofoni hapur</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
