@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Режим польоту вимкнено</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Вимикання звуку увімкнено</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Вимикання звуку вимкнено</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Збалансоване живлення</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Не вдалося увімкнути ефекти вікон</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>Вимкнути мікрофон</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>Увімкнути мікрофон</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
