@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>Chế độ máy bay tắt</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>Mute bật</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>Mute tắt</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>Mức năng lượng cân bằng</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>Không thể bật hiệu ứng cửa sổ</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
