@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>关闭飞行模式</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>开启静音</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>关闭静音</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>平衡模式</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>打开窗口特效失败</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>麦克风已关</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>麦克风已开</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
