@@ -49,14 +49,6 @@
         <source>Airplane mode off</source>
         <translation>關閉飛航模式</translation>
     </message>
-    <message>
-        <source>Mute on</source>
-        <translation>開啟靜音</translation>
-    </message>
-    <message>
-        <source>Mute off</source>
-        <translation>關閉靜音</translation>
-    </message>
     <message>
         <source>Balanced power</source>
         <translation>平衡模式</translation>
@@ -81,5 +73,13 @@
         <source>Failed to enable window effects</source>
         <translation>打開窗口特效失敗</translation>
     </message>
+    <message>
+        <source>Microphone off</source>
+        <translation>麥克風已關</translation>
+    </message>
+    <message>
+        <source>Microphone on</source>
+        <translation>麥克風已開</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
