@@ -49,9 +49,14 @@ NotificationManager::NotificationManager(QObject *parent)
     , m_persistence(DataAccessorProxy::instance())
     , m_setting(new NotificationSetting(this))
     , m_pendingTimeout(new QTimer(this))
+    , m_cleanupTimer(new QTimer(this))
 {
     m_pendingTimeout->setSingleShot(true);
     connect(m_pendingTimeout, &QTimer::timeout, this, &NotificationManager::onHandingPendingEntities);
+    
+    m_cleanupTimer->setInterval(1000); 
+    connect(m_cleanupTimer, &QTimer::timeout, this, &NotificationManager::onCleanupExpiredNotifications);
+    m_cleanupTimer->start();
 
     DataAccessorProxy::instance()->setSource(DBAccessor::instance());
 
@@ -77,7 +82,9 @@ NotificationManager::NotificationManager(QObject *parent)
     m_systemApps = config->value("systemApps").toStringList();
     // TODO temporary fix for AppNamesMap
     m_appNamesMap = config->value("AppNamesMap").toMap();
-
+    if(!config->value("notificationCleanupDays").isNull()) {
+        m_cleanupDays = config->value("notificationCleanupDays").toInt();
+    } 
     if (QStringLiteral("wayland") != QGuiApplication::platformName()) {
         initScreenLockedState();
     }
@@ -207,6 +214,8 @@ uint NotificationManager::Notify(const QString &appName, uint replacesId, const
     auto tsAppName = m_setting->appValue(appId, NotificationSetting::AppName).toString();
     if (tsAppName.isEmpty()) {
         tsAppName = appName;
+    } else {
+        qCDebug(notifyLog) << "AppName is translated from AM, which appId is:" << appId;
     }
 
     QString strBody = body;
@@ -455,6 +464,8 @@ void NotificationManager::updateEntityProcessed(qint64 id, uint reason)
     if (entity.isValid()) {
         if ((reason == NotifyEntity::Closed || reason == NotifyEntity::Dismissed) && entity.processedType() == NotifyEntity::NotProcessed) {
             entity.setProcessedType(NotifyEntity::Removed);
+        } else if (reason == NotifyEntity::Timeout) {
+            entity.setProcessedType(NotifyEntity::Removed);
         } else {
             entity.setProcessedType(NotifyEntity::Processed);
         }
@@ -673,4 +684,14 @@ void NotificationManager::onScreenLockedChanged(bool screenLocked)
     m_screenLocked = screenLocked;
 }
 
+void NotificationManager::onCleanupExpiredNotifications()
+{    
+    const qint64 cutoffTime = QDateTime::currentDateTime().addDays(-m_cleanupDays).toMSecsSinceEpoch();
+    auto expiredEntities = m_persistence->fetchExpiredEntities(cutoffTime);
+    
+    for (const auto &entity : expiredEntities) {
+        notificationClosed(entity.id(), entity.bubbleId(), NotifyEntity::Timeout);
+    }
+}
+
 } // notification
